==> vera_1.8.orig.tar.gz: vera-1.8/vera.h <==
@c -*-texinfo-*-
@c This is part of the GNU edition of V.E.R.A.
@c Copyright (C) 1993/2001 Oliver Heidelbach
@c See the file vera.texi for copying conditions.
@c 
@c Syntax:
@c ACRONYM
@c Expansion[ (Reference)][, "Style"]
@c Additional explanations are included in [square brackets]

@table @asis
@item H4P
High Performance Parallel Processing Project (ICI)

@item HACL
Host Access Class Library (HOD, API)

@item HACMP
High Availability Clustered Multi Processing (IBM, RS/6000, Bull), "HA/CMP"

@item HAL
Hard Array Logic

@item HAL
Hardware Abstraction Layer (Windows NT)

@item HAL
Heuristically programmed ALgorithmic computer (2001)

@item HALPC
Houston Area League of PC-Users, "HAL-PC" 

@item HAMPS
Host AUTODIN Message Processing System (AUTODIN, mil.)

@item HAND
Have A Nice Day (slang, Usenet, IRC)

@item HANFS
Highly Available Network File System

@item HAP
Host Access Protocol (RFC 907/1221)

@item HAS
High Availability Subsystem (Bull)

@item HAT
Hashed Address Table

@item HAVI
Home Audio Video Interoperability (org., Grundig, Hitachi, Matsushita, Philips, Sharp, Sony, Thomson, Toshiba)

@item HBA
Host Bus Adapter (SCSI)

@item HBCI
HomeBanking Computer Interface Internet, banking, Germany, HBCI

@item HBT
Hetero Bipolar Transistor (IBM, IC)

@item HCI
Human Computer Interaction (BCS, conference)

@item HCL
Hardware Compatibility List (MS, Windows)

@item HCL
Host Control Links

@item HCSDS
High Capacity Satellite Digital Service

@item HCSS
High Capacity Storage System (Novell, Netware)

@item HCT
Hamburger ComputerTage (fair)

@item HCT
High-speed CMOS [logic] with TTT-compatible [logic] levels (IC, MOS)

@item HCTDS
High-Capacity Terrestrial Digital Service

@item HD
High Density

@item HDAM
Hierarchical Direct Access Method (DAM)

@item HDB
HoneyDanBer [standard] (Unix)

@item HDB3
High Density Bipolar 3

@item HDBMS
Hierarchical DataBase Management System (DBMS, DB)

@item HDC
Hard Disk Controller

@item HDCD
High Density Compact Disk (CD, Sony, Phillips)

@item HDD
Hard Disk Drive (HDD)

@item HDD
Highly Doped Drain (IC, MOSFET)

@item HDF
Hierarchical Data Format (NCSA)

@item HDH
HDLC Distant Host

@item HDI
HOOPS Device Interface (VAGI)

@item HDIT
High Bandwidth Differential Interconnect Technology [bus] (VIA)

@item HDL
Hardware Description Language (ASIC)

@item HDLC
High-level Data Link Control (ISO)

@item HDM
Hardware Device Module (I2O)

@item HDML
Handheld Device Markup Language (mobile-systems, HDTP)

@item HDN
Hochgeschwindigkeits-DatenNetz

@item HDOS
Heath Disk Operating System (OS, Heath)

@item HDR
High availability Data Replication (Informix, DB)

@item HDR
High Dynamic Range

@item HDSL
High data / bit rate Digital Subscriber Line (BELLCORE, AT&T, DSL)

@item HDSL
High-level Data Specification Language

@item HDTP
Handheld Device Transport Protocol (mobile-systems)

@item HDX
Half DupleX

@item HE
HoehenEinheit [1HE = 19"]

@item HEA
Hyundai Electronics of America (manufacturer)

@item HEC
Header Error Check

@item HEC
Header Error Control (ATM)

@item HECTOR
HEterogeneous Computer TOgetheR (IBM, Uni Karlsruhe, Germany)

@item HEL
Hardware Emulation Layer

@item HEL
Header Extension Length

@item HEMT
High Electron Mobility Transistor

@item HEPNET
High Energy Physics NETwork (network)

@item HERMES
Heuristic Emergency Response Management Expert System (XPS)

@item HERODE
Handling the Electronic Representation of mixed text - image Office Documents based on ECMA standard 101 (ESPRIT, SNI, TITN, ECMA, ODA)

@item HES
Home Electronic System (SNI)

@item HES
Honeywell Executive System (OS, Honeywell 800)

@item HF
Have Fun (slang, Usenet, IRC)

@item HFC
Hybrid Fiber Coax [network]

@item HFD
Hauptanschluss fuer Direktruf / Datenleitung (Telekom), "HfD" 

@item HFDS
Highly Functional Distributed System (MTRON)

@item HFS
Hierachical File System (Apple, CD)

@item HFT
High Function Terminal (AIX, IBM)

@item HGA
Hercules Graphics Adapter

@item HGC
Hercules Graphics Card

@item HHI
Heinrich Hertz Institut Org., Germany

@item HI
Hochschulverband Informationswissenschaften (org.)

@item HIC
Human Interaction Component

@item HIC
Hybrid Integrated Circuit

@item HID
Human Interface Device (MS)

@item HIDAM
Hierarchical Indexed Direct Access Method (DAM)

@item HIFD
HIgh capacity Floppy Disk (Sony, Fuji), "HiFD"

@item HIFI
Hypertext Interface For Information (ESPRIT)

@item HIFIVE
HIgh Fidelity Interactive Visual Environment (DEC), "Hi-FIVE"

@item HIFT
Hardware Implemented Fault Tolerance (SIFT)

@item HIGGENS
Human Interface Graphical GENeration System (Uni Colorado)

@item HINT
Hierarchical INTegration [benchmark]

@item HIPERLAN
HIgh PErformance Radio Local Area Network (LAN, ETSI, EN 300 652)

@item HIPPI
HIgh Performance Parallel Interface

@item HIPPI
High Performance Peripheral Interface

@item HIRD
HURD of Interface Representing Depth (GNU, HURD)

@item HISAM
Hierarchical Indexed Sequential Acess Method (SAM)

@item HISP
HIgh SPeed channel connector (Cray, I/O)

@item HLL
High Level Language

@item HLLAPI
High Level Language Application Programming Interface (IBM, API)

@item HLPI
Higher Layer Protocol Identifier

@item HLR
Home Location Register (LR, GSM, GPRS, mobile-systems)

@item HLS
Hue, Luminance, Saturation (color system, DTP)

@item HMA
High Memory Area

@item HMAC
keyed-Hashing for Message AuthentiCation (cryptography, RFC 2104)

@item HMC
Highspeed Memory Controller (Apple)

@item HMD
Head Mounted Display (VR)

@item HMI
Human-Machine Interface

@item HMMP
HyperMedia Management Protocol (MS, Intel, Cisco, WWW, HMMS)

@item HMMS
HyperMedia Management Schema (MS, Intel, Cisco, WWW)

@item HMOS
High performance Metal Oxide Semiconductor (IC)

@item HMP
Host Monitoring Protocol (RFC 869)

@item HMUX
Hybrid MUltipleXer (FDDI), "H-MUX"

@item HNF
Heinz Nixdorf Museumsforum (org., Paderborn, Germany)

@item HNI
Heinz Nixdorf Institut (org., ZIT)

@item HOD
Host On Demand (IBM, HOD)

@item HOL
Head Of Line

@item HOLAP
Hybrid OnLine Analytical Processing (OLAP, DB)

@item HOMERF
Home Radio Frequency (WLAN), "HomeRF"

@item HOOPS
Hierarchical Object Orientated Picture System (Ithaca, Autodesk, OOP)

@item HOP
Homecast Open Protocol (WLAN, Alation Systems)

@item HP
Hewlett Packard (manufacturer)

@item HPA
High Performance Architecture (HP)

@item HPBIDS
Hewlett Packard Broadband Internet Delivery System (HP, Internet), "HP BIDS"

@item HPC
Handheld Personal Computer (PC), "H/PC"

@item HPC
High Performance Computing

@item HPCC
High Performance Computing and Communication

@item HPCS
High Performance Communication Server (Tobit, NLM, Netware)

@item HPF
High Performance FORTRAN (FORTRAN)

@item HPFS
High Performance FileSystem (OS/2)

@item HPGL
Hewlett Packard Graphics Language (CAD, CAM, HP)

@item HPIB
Hewlett Packard Interface Bus (GPIB)

@item HPM
Hyper Page Mode

@item HPMI
??? [Schnittstelle] (CAD), "HP-MI"

@item HPNA
???

@item HPOFS
High Performance Optical File System (IBM, OS/2, MOD)

@item HPPA
Hewlett Packard Precision Architecture (HP, RISC)

@item HPPCL
Hewlett Packard Printer Control Language

@item HPR
High Performance Routing

@item HPR
High Priority Request (VUMA)

@item HPTS
High Performance Transaction Systems

@item HPUX
Hewlett Packard / UniX (Unix), "HP/UX" 

@item HPVEE
Hewlett-Packard Visual Engineering Environment (HP, GUI), "HP VEE"

@item HPVUE
Hewlett Packard - Visual User Environment (HP, GUI), "HP-VUE"

@item HR
High Rate (IEEE 802.11)

@item HRC
Hybrid Ring Control (FDDI)

@item HRFWG
Home Radio Frequency Working Group (WLAN, HOMERF)

@item HS
High Speed (MODEM)

@item HSA
High Speed Access

@item HSB
Hue Saturation Brightness (DTP)

@item HSC
Hierarchical Storage Controller

@item HSC
HTML Sucks Completely (HTML, Amiga)

@item HSCDS
High Speed Cable Data Services

@item HSCSD
High Speed Circuit Switched Data (GSM, mobile-systems)

@item HSDRAM
??? Random Access Memory (RAM, DRAM, IC)

@item HSFS
High Sierra File System

@item HSI
High Speed Interface

@item HSI
Hue, Saturation, Intensity (DTP)

@item HSIS
??? High Speed Interface / SNA, "HSI/S" 

@item HSLAN
High Speed Local Area Network, "HS-LAN" 

@item HSLFX
??? [hardware description language] (HDL, NTT, LSI), "HSL-FX"

@item HSLN
High Speed Local Network

@item HSM
Hardware Specific Module (ODI)

@item HSM
Hierarchical Storage Management

@item HSM
Hierarchisches SpeicherManagement

@item HSMD
High Speed Mobile Data HSCSD, Germany, E-Plus

@item HSP
[UUNet] HighSpeed Peering

@item HSP
Host Signal Processing (DFUe, WinModem)

@item HSRP
Hot Standby Router Protocol (Cisco, IOS)

@item HSSDS
High-Speed Switched Digital Service

@item HSSI
High Speed Serial Interface

@item HSSN
HighSpeed Switching Network (Cray, ATM)

@item HST
Hawaiian Standard Time [-1030] (TZ)

@item HST
High Soft Tech (manufacturer, ISDN)

@item HST
High Speed Technology (US Robotics)

@item HT
Horizontal Tab

@item HTDM
Hybrid Time Division Multiplexing [protocol]

@item HTF
Hyper-g Text Format (Hyper-G)

@item HTH
Hope This Helps (slang)

@item HTML
HyperText Markup Language (Internet, WWW, SGML, RFC 1866/1942, HTML)

@item HTPS
High Temperature PolySilicon

@item HTSI
Host Transport Service Interface (ICC, CT-API)

@item HTTP
HyperText Transfer Protocol (WWW, RFC 2068)

@item HTTPD
HyperText Transfer Protocol DAEMON (WWW, HTTP)

@item HTTPNG
HyperText Transfer Protocol - Next Generation (WWW), "HTTP-NG"

@item HTTPS
HyperText Transfer Protocol [SSL] Secured (HTTP, SSL, WWW)

@item HUGO
Holland User Group for OS/2 (org., user group, OS/2, Netherlands)

@item HURD
HIRD of Unix-Replacing DAEMONs (GNU, HIRD)

@item HVC
Hue-Value-Chroma [model] (Tektronic, DTP)

@item HVD
High Voltage Differential [technology] (SCSI)

@item HWMC
HardWare Motion Compensation

@item HYCH
Hope You Can Help (slang, Usenet, IRC)

@item HYTEA
HYperText Environment for Authoring (ESPRIT)

@item HYTIME
Hypermedia/Time-based structuring language (SGML, ISO, IEC, IS 10744), "HyTime"

@end table

==> vera_1.12.orig.tar.gz: vera-1.12/vera.h <==
@c -*-texinfo-*-
@c This is part of the GNU edition of V.E.R.A.
@c Copyright (C) 1993/2003 Oliver Heidelbach
@c See the file vera.texi for copying conditions.
@c 
@c Syntax:
@c ACRONYM
@c Expansion[ (Reference)][, "Style"]
@c Additional explanations are included in [square brackets]

@table @asis
@item H2U
Higher capacity to UMTS (UMTS, WLAN)

@item H4P
High Performance Parallel Processing Project (ICI)

@item HAAPI
Human Authentication Application Program Interface (API), "HA-API"

@item HACL
Host Access Class Library (HOD, API)

@item HACMP
High Availability Clustered Multi Processing (IBM, RS/6000, Bull), "HA/CMP"

@item HAL
Hard Array Logic

@item HAL
Hardware Abstraction Layer (Windows NT)

@item HAL
Heuristically programmed ALgorithmic computer (2001)

@item HALPC
Houston Area League of PC-Users, "HAL-PC" 

@item HAMPS
Host AUTODIN Message Processing System (AUTODIN, mil.)

@item HAND
Have A Nice Day (slang, Usenet, IRC)

@item HANFS
Highly Available Network File System

@item HAP
Host Access Protocol (RFC 907/1221)

@item HAS
High Availability Subsystem (Bull)

@item HAT
Hashed Address Table

@item HAV
High AVailability

@item HAVI
Home Audio Video Interoperability (org., Grundig, Hitachi, Matsushita, Philips, Sharp, Sony, Thomson, Toshiba)

@item HBA
Host Bus Adapter (SCSI)

@item HBCI
HomeBanking Computer Interface Internet, banking, Germany, HBCI

@item HBT
Hetero Bipolar Transistor (IBM, IC)

@item HC
Handler Compiler (SAX, XML)

@item HCA
Host Channel Adapter (Infini-Band)

@item HCF
Hybrid Coordination Function (MAC, 802.11a)

@item HCI
Host Controller Interface (Bluetooth, Linux)

@item HCI
Human Computer Interaction (BCS, conference)

@item HCL
Hardware Certification List (TCPA)

@item HCL
Hardware Compatibility List (MS, Windows)

@item HCL
Host Control Links

@item HCSDS
High Capacity Satellite Digital Service

@item HCSS
High Capacity Storage System (Novell, Netware)

@item HCT
Hamburger ComputerTage (fair)

@item HCT
High-speed CMOS [logic] with TTT-compatible [logic] levels (IC, MOS)

@item HCTDS
High-Capacity Terrestrial Digital Service

@item HD
High Density

@item HDAM
Hierarchical Direct Access Method (DAM)

@item HDB
HoneyDanBer [standard] (Unix)

@item HDB3
High Density Bipolar 3

@item HDBMS
Hierarchical DataBase Management System (DBMS, DB)

@item HDC
Hard Disk Controller

@item HDCD
High Density Compact Disk (CD, Sony, Phillips)

@item HDD
Hard Disk Drive (HDD)

@item HDD
Highly Doped Drain (IC, MOSFET)

@item HDDV
High Definition Digital Video (video)

@item HDF
Hierarchical Data Format (NCSA)

@item HDH
HDLC Distant Host

@item HDI
HOOPS Device Interface (VAGI)

@item HDIT
High Bandwidth Differential Interconnect Technology [bus] (VIA)

@item HDL
Hardware Description Language (ASIC)

@item HDLC
High-level Data Link Control (ISO)

@item HDM
Hardware Device Module (I2O)

@item HDML
Handheld Device Markup Language (mobile-systems, HDTP)

@item HDN
Hochgeschwindigkeits-DatenNetz

@item HDOP
Horizontal Dilution Of Precision (GPS)

@item HDOS
Heath Disk Operating System (OS, Heath)

@item HDR
High availability Data Replication (Informix, DB)

@item HDR
High Dynamic Range

@item HDSL
High data / bit rate Digital Subscriber Line (BELLCORE, AT&T, DSL, BIT)

@item HDSL
High-level Data Specification Language

@item HDTP
Handheld Device Transport Protocol (mobile-systems)

@item HDX
Half DupleX

@item HE
HoehenEinheit [1HE = 19"]

@item HEA
Hyundai Electronics of America (manufacturer)

@item HEC
Header Error Check

@item HEC
Header Error Control (ATM)

@item HECTOR
HEterogeneous Computer TOgetheR (IBM, Uni Karlsruhe, Germany)

@item HEL
Hardware Emulation Layer

@item HEL
Header Extension Length

@item HEMT
High Electron Mobility Transistor

@item HEPNET
High Energy Physics NETwork (network)

@item HERMES
Heuristic Emergency Response Management Expert System (XPS)

@item HERODE
Handling the Electronic Representation of mixed text - image Office Documents based on ECMA standard 101 (ESPRIT, SNI, TITN, ECMA, ODA)

@item HES
Home Electronic System (SNI)

@item HES
Honeywell Executive System (OS, Honeywell 800)

@item HF
Have Fun (slang, Usenet, IRC)

@item HFC
Hybrid Fiber Coax [network]

@item HFD
Hauptanschluss fuer Direktruf / Datenleitung (DTAG), "HfD" 

@item HFDS
Highly Functional Distributed System (MTRON)

@item HFP
Hands Free Profile (Bluetooth, SPP)

@item HFS
Hierachical File System (Apple, CD, MACOS)

@item HFT
High Function Terminal (AIX, IBM)

@item HGA
Hercules Graphics Adapter

@item HGC
Hercules Graphics Card

@item HHI
Heinrich Hertz Institut Org., Germany

@item HI
Hochschulverband Informationswissenschaften (org.)

@item HI1
Handover Interface 1 (ETSI, ES 201671)

@item HI2
Handover Interface 2 (ETSI, ES 201671)

@item HI3
Handover Interface 3 (ETSI, ES 201671)

@item HIC
Human Interaction Component

@item HIC
Hybrid Integrated Circuit

@item HID
Human Interface Device (MS)

@item HIDAM
Hierarchical Indexed Direct Access Method (DAM)

@item HIFD
HIgh capacity Floppy Disk (Sony, Fuji), "HiFD"

@item HIFI
Hypertext Interface For Information (ESPRIT)

@item HIFIVE
HIgh Fidelity Interactive Visual Environment (DEC), "Hi-FIVE"

@item HIFT
Hardware Implemented Fault Tolerance (SIFT)

@item HIGGENS
Human Interface Graphical GENeration System (Uni Colorado)

@item HINT
Hierarchical INTegration [benchmark]

@item HIPERLAN
HIgh PErformance Radio Local Area Network (LAN, ETSI, EN 300 652)

@item HIPPI
HIgh Performance Parallel Interface

@item HIPPI
High Performance Peripheral Interface

@item HIRD
HURD of Interface Representing Depth (GNU, HURD)

@item HISAM
Hierarchical Indexed Sequential Acess Method (SAM)

@item HISP
HIgh SPeed channel connector (Cray, I/O)

@item HLL
High Level Language

@item HLLAPI
High Level Language Application Programming Interface (IBM, API)

@item HLP
High Latency Profile (video, AVC)

@item HLPI
Higher Layer Protocol Identifier

@item HLR
Home Location Register (LR, GSM, GPRS, mobile-systems)

@item HLS
Hue, Luminance, Saturation (color system, DTP)

@item HLSL
High Level Shader Language (DirectX)

@item HMA
High Memory Area

@item HMAC
keyed-Hashing for Message AuthentiCation (cryptography, RFC 2104)

@item HMC
Highspeed Memory Controller (Apple)

@item HMD
Head Mounted Display (VR)

@item HMI
Human-Machine Interface

@item HMMP
HyperMedia Management Protocol (MS, Intel, Cisco, WWW, HMMS)

@item HMMS
HyperMedia Management Schema (MS, Intel, Cisco, WWW)

@item HMOS
High performance Metal Oxide Semiconductor (IC)

@item HMP
Host Monitoring Protocol (RFC 869)

@item HMUX
Hybrid MUltipleXer (FDDI), "H-MUX"

@item HNA
Host and Network Association [message] (OLSR)

@item HNF
Heinz Nixdorf Museumsforum (org., Paderborn, Germany)

@item HNI
Heinz Nixdorf Institut (org., ZIT)

@item HOD
Host On Demand (IBM, HOD)

@item HOL
Head Of Line

@item HOLAP
Hybrid OnLine Analytical Processing (OLAP, DB)

@item HOMERF
Home Radio Frequency (WLAN), "HomeRF"

@item HOOPS
Hierarchical Object Orientated Picture System (Ithaca, cardesk, OOP)

@item HOP
Homecast Open Protocol (WLAN, Alation Systems)

@item HOS
High Order Surfaces (3D)

@item HP
Hewlett Packard (manufacturer)

@item HPA
High Performance Architecture (HP)

@item HPBIDS
Hewlett Packard Broadband Internet Delivery System (HP, Internet), "HP BIDS"

@item HPC
Handheld Personal Computer (PC), "H/PC"

@item HPC
High Performance Computing

@item HPCC
High Performance Computing and Communication

@item HPCS
High Performance Communication Server (Tobit, NLM, Netware)

@item HPCS
High Productivity Computing System (DARPA, Cray, IBM, Sun, ...)

@item HPF
High Performance FORTRAN (FORTRAN)

@item HPFS
High Performance FileSystem (OS/2)

@item HPGL
Hewlett Packard Graphics Language (CAD, CAM, HP)

@item HPIB
Hewlett Packard Interface Bus (GPIB)

@item HPM
Hyper Page Mode

@item HPMI
Hewlett Packard Model Interface (CAD, HP), "HP-MI"

@item HPNA
???

@item HPOFS
High Performance Optical File System (IBM, OS/2, MOD)

@item HPPA
Hewlett Packard Precision Architecture (HP, RISC)

@item HPPCL
Hewlett Packard Printer Control Language

@item HPR
High Performance Routing

@item HPR
High Priority Request (VUMA)

@item HPTS
High Performance Transaction Systems

@item HPUX
Hewlett Packard / UniX (Unix), "HP/UX" 

@item HPVEE
Hewlett-Packard Visual Engineering Environment (HP, GUI), "HP VEE"

@item HPVUE
Hewlett Packard - Visual User Environment (HP, GUI), "HP-VUE"

@item HR
High Rate (IEEE 802.11)

@item HRC
Hybrid Ring Control (FDDI)

@item HRFWG
Home Radio Frequency Working Group (WLAN, HOMERF)

@item HRTF
Head Related Transfer Function

@item HS
High Speed (MODEM)

@item HSA
High Speed Access

@item HSB
Hue Saturation Brightness (DTP)

@item HSC
Hierarchical Storage Controller

@item HSC
HTML Sucks Completely (HTML, Amiga)

@item HSCDS
High Speed Cable Data Services

@item HSCSD
High Speed Circuit Switched Data (GSM, mobile-systems)

@item HSDRAM
High-speed Synchronous Random Access Memory (RAM, DRAM, IC)

@item HSFS
High Sierra File System

@item HSI
High Speed Interface

@item HSI
Hue, Saturation, Intensity (DTP)

@item HSIS
??? High Speed Interface / SNA, "HSI/S" 

@item HSLAN
High Speed Local Area Network, "HS-LAN" 

@item HSLFX
Hierarchical Specification Language - Function Extension (HDL, NTT, LSI), "HSL-FX"

@item HSLN
High Speed Local Network

@item HSM
Hardware Specific Module (ODI)

@item HSM
Hierarchical Storage Management

@item HSM
Hierarchisches SpeicherManagement

@item HSMD
High Speed Mobile Data HSCSD, Germany, E-Plus

@item HSP
[UUNet] HighSpeed Peering

@item HSP
Host Signal Processing (telecommunication, WinModem)

@item HSR
Hidden Surface Removal (3D)

@item HSRP
Hot Standby Router Protocol (Cisco, IOS)

@item HSSDS
High-Speed Switched Digital Service

@item HSSI
High Speed Serial Interface

@item HSSN
HighSpeed Switching Network (Cray, ATM)

@item HST
Hawaiian Standard Time [-1030] (TZ)

@item HST
High Soft Tech (manufacturer, ISDN)

@item HST
High Speed Technology (US Robotics)

@item HT
Horizontal Tab

@item HT
Hyper-Threading (Intel, Pentium, SMT, CPU)

@item HTC
HTML Components (MS, OWA, WWW, HTML)

@item HTDM
Hybrid Time Division Multiplexing [protocol]

@item HTF
Hyper-g Text Format (Hyper-G)

@item HTH
Hope This Helps (slang)

@item HTML
HyperText Markup Language (Internet, WWW, SGML, RFC 1866/1942, HTML)

@item HTPC
Home Theater Personal Computer (PC)

@item HTPS
High Temperature PolySilicon

@item HTSI
Host Transport Service Interface (ICC, CT-API)

@item HTTP
HyperText Transfer Protocol (WWW, RFC 2068)

@item HTTPD
HyperText Transfer Protocol DAEMON (WWW, HTTP)

@item HTTPNG
HyperText Transfer Protocol - Next Generation (WWW), "HTTP-NG"

@item HTTPR
HyperText Transfer Protocol - Reliable (HTTP, IBM)

@item HTTPS
HyperText Transfer Protocol [SSL] Secured (HTTP, SSL, WWW)

@item HUD
Head-Up Display (AG)

@item HUGO
Holland User Group for OS/2 (org., user group, OS/2, Netherlands)

@item HURD
HIRD of Unix-Replacing DAEMONs (GNU, HIRD)

@item HVC
Hue-Value-Chroma [model] (Tektronic, DTP)

@item HVD
High Voltage Differential [technology] (SCSI)

@item HWMC
HardWare Motion Compensation

@item HYCH
Hope You Can Help (slang, Usenet, IRC)

@item HYTEA
HYperText Environment for Authoring (ESPRIT)

@item HYTIME
Hypermedia/Time-based structuring language (SGML, ISO, IEC, IS 10744), "HyTime"

@item HYTM
HyTime Topic Map (SGML, KM), "HyTM"

@end table
